==> rustsec-admin-0.4.2.crate: rustsec-admin-0.4.2/README.md <==
# `rustsec-admin`: RustSec Advisory DB Admin Utility

[![Latest Version][crate-image]][crate-link]
[![Docs][docs-image]][docs-link]
[![Build Status][build-image]][build-link]
[![Safety Dance][safety-image]][safety-link]
![MSRV][rustc-image]
![Apache 2.0 OR MIT licensed][license-image]
[![Project Chat][chat-image]][chat-link]

The `rustsec-admin` CLI app is an administrative utility for maintaining the
RustSec Advisory Database.

Unless you are a RustSec maintainer, you don't need to use this utility.
Please see the [cargo-audit] utility instead.

## License

Licensed under either of:

- Apache License, Version 2.0 ([LICENSE-APACHE] or https://www.apache.org/licenses/LICENSE-2.0)
- MIT license ([LICENSE-MIT] or https://opensource.org/licenses/MIT)

at your option.

### Contribution

Unless you explicitly state otherwise, any contribution intentionally submitted
for inclusion in the work by you shall be dual licensed as above, without any
additional terms or conditions.

[//]: # (badges)

[crate-image]: https://img.shields.io/crates/v/rustsec-admin.svg
[crate-link]: https://crates.io/crates/rustsec-admin
[docs-image]: https://docs.rs/rustsec-admin/badge.svg
[docs-link]: https://docs.rs/rustsec-admin/
[build-image]: https://github.com/rustsec/rustsec-admin/workflows/CI/badge.svg
[build-link]: https://github.com/RustSec/platforms-crate/actions?query=workflow:CI
[safety-image]: https://img.shields.io/badge/unsafe-forbidden-success.svg
[safety-link]: https://github.com/rust-secure-code/safety-dance/
[rustc-image]: https://img.shields.io/badge/rustc-1.35+-blue.svg
[license-image]: https://img.shields.io/badge/license-Apache2.0%2FMIT-blue.svg
[chat-image]: https://img.shields.io/badge/zulip-join_chat-blue.svg
[chat-link]: https://rust-lang.zulipchat.com/#narrow/stream/146229-wg-secure-code/

[//]: # (general links)

[cargo-audit]: https://github.com/RustSec/cargo-audit
[LICENSE-APACHE]: https://github.com/RustSec/rustsec-admin/blob/main/LICENSE-APACHE
[LICENSE-MIT]: https://github.com/RustSec/rustsec-admin/blob/main/LICENSE-MIT

==> rustsec-admin-0.4.3.crate: rustsec-admin-0.4.3/README.md <==
# `rustsec-admin`: RustSec Advisory DB Admin Utility

[![Latest Version][crate-image]][crate-link]
[![Docs][docs-image]][docs-link]
[![Build Status][build-image]][build-link]
[![Safety Dance][safety-image]][safety-link]
![MSRV][rustc-image]
![Apache 2.0 OR MIT licensed][license-image]
[![Project Chat][chat-image]][chat-link]

The `rustsec-admin` CLI app is an administrative utility for maintaining the
RustSec Advisory Database.

Unless you are a RustSec maintainer, you don't need to use this utility.
Please see the [cargo-audit] utility instead.

## License

Licensed under either of:

- Apache License, Version 2.0 ([LICENSE-APACHE] or https://www.apache.org/licenses/LICENSE-2.0)
- MIT license ([LICENSE-MIT] or https://opensource.org/licenses/MIT)

at your option.

### Contribution

Unless you explicitly state otherwise, any contribution intentionally submitted
for inclusion in the work by you shall be dual licensed as above, without any
additional terms or conditions.

[//]: # (badges)

[crate-image]: https://img.shields.io/crates/v/rustsec-admin.svg
[crate-link]: https://crates.io/crates/rustsec-admin
[docs-image]: https://docs.rs/rustsec-admin/badge.svg
[docs-link]: https://docs.rs/rustsec-admin/
[build-image]: https://github.com/RustSec/rustsec/actions/workflows/admin.yml/badge.svg
[build-link]: https://github.com/RustSec/rustsec/actions/workflows/admin.yml
[safety-image]: https://img.shields.io/badge/unsafe-forbidden-success.svg
[safety-link]: https://github.com/rust-secure-code/safety-dance/
[rustc-image]: https://img.shields.io/badge/rustc-1.35+-blue.svg
[license-image]: https://img.shields.io/badge/license-Apache2.0%2FMIT-blue.svg
[chat-image]: https://img.shields.io/badge/zulip-join_chat-blue.svg
[chat-link]: https://rust-lang.zulipchat.com/#narrow/stream/146229-wg-secure-code/

[//]: # (general links)

[cargo-audit]: https://github.com/RustSec/cargo-audit
[LICENSE-APACHE]: https://github.com/RustSec/rustsec-admin/blob/main/LICENSE-APACHE
[LICENSE-MIT]: https://github.com/RustSec/rustsec-admin/blob/main/LICENSE-MIT
